package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaCheck;
import com.example.civilizedcity.service.TaCheckService;

 /**
 * 模拟测评;(ta_check)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-12
 */
@Api(tags = "模拟测评对象功能接口")
@RestController
@RequestMapping("/")
public class TaCheckController extends BaseController {
    
    @Autowired
    private TaCheckService taCheckService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param checkId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taCheck/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taCheckService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taCheck")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaCheck> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<taCheck> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaCheck> result = taCheckService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taCheck 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taCheck")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaCheck taCheck) throws Exception {
        taCheckService.save(taCheck);
        return ResponseBean.success(taCheck);
    }
    
    /** 
     * 更新数据
     *
     * @param taCheck 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taCheck/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaCheck taCheck,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taCheckService.updateById(taCheck);
        return ResponseBean.success(taCheck);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param checkId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taCheck/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taCheckService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}