package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaIssue;
import com.example.civilizedcity.service.TaIssueService;

 /**
 * 问题表;(ta_issue)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-12
 */
@Api(tags = "问题表对象功能接口")
@RestController
@RequestMapping("/")
public class TaIssueController extends BaseController {
    
    @Autowired
    private TaIssueService taIssueService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param issueId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taIssue/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(taIssueService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taIssue")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaIssue> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaIssue> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaIssue> result = taIssueService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taIssue 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taIssue")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaIssue taIssue) throws Exception {
        taIssueService.save(taIssue);
        return ResponseBean.success(taIssue);
    }
    
    /** 
     * 更新数据
     *
     * @param taIssue 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taIssue/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaIssue taIssue,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        taIssueService.updateById(taIssue);
        return ResponseBean.success(taIssue);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param issueId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taIssue/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        taIssueService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}